import { ChangeDetectorRef, OnInit, OnChanges, OnDestroy, EventEmitter } from '@angular/core';
import { Subject } from 'rxjs/Subject';
import { Subscription } from 'rxjs/Subscription';
import { ResizeEvent } from 'angular-resizable-element';
import { CalendarEvent } from '../../utils/CalendarEvent';
import { Calendar } from '../../utils/Calendar';
import { CalendarEventTimesChangedEvent } from '../../utils/CalendarEventTimesChangedEvent';
import { DayViewHour } from '../../utils/day/DayViewHour';
import { DayView } from '../../utils/day/DayView';
import { DayViewEvent } from '../../utils/day/DayViewEvent';
import { DayViewEventResize } from '../../utils/day/DayViewEventResize';
import { CalendarUtilsService } from './../../utils/calendar-utils.service';
import { DayViewHourSegment } from '../../utils/day/DayViewHourSegment';
export declare class DayViewComponent implements OnInit, OnChanges, OnDestroy {
    private cdr;
    private utils;
    /**
     * The current view date
    */
    viewDate: Date;
    /**
     * An array of events to display on view
    */
    events: CalendarEvent[];
    /**
     * An array of events to display on view
    */
    calendars: Calendar[];
    /**
     * The number of segments in an hour. Must be <= 6
    */
    hourSegments: number;
    /**
     * The height in pixels of each hour segment
    */
    hourSegmentHeight: number;
    /**
     * The day start hours in 24 hour time. Must be 0-23
    */
    dayStartHour: number;
    /**
     * The day start minutes. Must be 0-59
    */
    dayStartMinute: number;
    /**
     * The day end hours in 24 hour time. Must be 0-23
    */
    dayEndHour: number;
    /**
     * The day end minutes. Must be 0-59
    */
    dayEndMinute: number;
    /**
     * The width in pixels of each event on the view
    */
    eventWidth: number;
    /**
     * An observable that when emitted on will re-render the current view
    */
    refresh: Subject<any>;
    /**
     * The locale used to format dates
    */
    locale: string;
    /**
     * The grid size to snap resizing and dragging of events to
    */
    eventSnapSize: number;
    /**
     * Called when an event title is clicked
    */
    eventClicked: EventEmitter<{
        event: CalendarEvent;
    }>;
    /**
     * Called when an hour segment is clicked
    */
    hourSegmentClicked: EventEmitter<{
        date: Date;
    }>;
    /**
     * Called when an event is resized or dragged and dropped
     */
    eventTimesChanged: EventEmitter<CalendarEventTimesChangedEvent>;
    /**
     * An output that will be called before the view is rendered for the current day.
     * If you add the `cssClass` property to a segment it will add that class to the hour segment in the template
    */
    beforeViewRender: EventEmitter<{
        body: DayViewHour[];
    }>;
    /**
     * @hidden
    */
    hours: DayViewHour[];
    /**
     * @hidden
    */
    view: DayView;
    /**
     * @hidden
    */
    width: number;
    /**
     * @hidden
    */
    refreshSubscription: Subscription;
    /**
     * @hidden
    */
    currentResizes: Map<DayViewEvent, DayViewEventResize>;
    /**
     * @hidden
    */
    validateDrag: (args: any) => boolean;
    /**
     * @hidden
    */
    validateResize: (args: any) => boolean;
    constructor(cdr: ChangeDetectorRef, utils: CalendarUtilsService, locale: string);
    ngOnInit(): void;
    ngOnChanges(changes: any): void;
    ngOnDestroy(): void;
    eventDropped(dropEvent: {
        dropData?: {
            event?: CalendarEvent;
        };
    }, segment: DayViewHourSegment): void;
    resizeStarted(event: DayViewEvent, resizeEvent: ResizeEvent, dayViewContainer: HTMLElement): void;
    resizing(event: DayViewEvent, resizeEvent: ResizeEvent): void;
    resizeEnded(dayEvent: DayViewEvent): void;
    dragStart(event: HTMLElement, dayViewContainer: HTMLElement): void;
    eventDragged(dayEvent: DayViewEvent, draggedInPixels: number): void;
    private refreshHourGrid();
    private refreshView();
    private refreshAll();
}
